# summarizer4u  [![Downloads](https://static.pepy.tech/personalized-badge/summarizer4u?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads)](https://pepy.tech/project/summarizer4u)

Get your text summarized !

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install.

```bash
pip install summarizer4u
```

## Install from source

```bash
cd summarizer4u 
python setup.py
```

## Usage

```python
from summarizer4u import summary

text = summary("your text to get summarized go here")

print(text)
```

## License
[MIT](https://choosealicense.com/licenses/mit/)
